%
% Simple One-vs-All (OVA) multiclass coding utility function.
%
% [y, classes] = ova(y, classes)
%
% Input:
% y -- class labels
% [optional] classes -- OVA code
%
% Output:
% y -- OVA matrix in {-1,+1}^{# examples X # classes}
% classes -- vector encoding position of classes in OVA coding
%
% Contact the author: ilja.kuzborskij [at] idiap.ch
%                     http://idiap.ch/~ikuzbor
%
% ----------------------------------------------------------------------------------
%
% Copyright (c) 2014 Idiap Research Institute, http://www.idiap.ch/
% Written by Ilja Kuzborskij <ilja.kuzborskij@idiap.ch>
%
% This file is part of MULTIpLE.
%
% MULTIpLE is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License version 3 as
% published by the Free Software Foundation.
%
% MULTIpLE is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with MULTIpLE. If not, see <http://www.gnu.org/licenses/>.
%
function [y, classes] = ova(y, classes)
    if nargin == 1
        classes = unique(y);
    end
    codes = arrayfun(@(c) 2*(y==c)-1, classes, 'UniformOutput', 0);
    y = [codes{:}];
end
